Index: /issm/trunk-jpl/src/m/classes/organizer.m
===================================================================
--- /issm/trunk-jpl/src/m/classes/organizer.m	(revision 20209)
+++ /issm/trunk-jpl/src/m/classes/organizer.m	(revision 20210)
@@ -1,3 +1,3 @@
 %ORGANIZER class definition
 %
 %   Supported options:
@@ -5,13 +5,12 @@
 %      prefix:     prefix for saved model names
 %      steps:      requested steps
-%      trunkprefix:prefix of previous run with a different prefix. Used to branch.
 %
 %   Usage:
-%      org = organizer(varargin)
+%      org = xorganizer(varargin)
 %
 %   Examples:
-%      org = organizer('repository','Models/','prefix','AGU2015','steps',0);  %build an empty organizer object with a given repository
+%      org = xorganizer('repository','Models/','prefix','AGU2015','steps',0);  %build an empty organizer object with a given repository
 
-classdef organizer < handle
+classdef xorganizer < handle
     properties (SetAccess=private) 
 		% {{{
@@ -21,16 +20,10 @@
 		repository    ='./';
 		prefix        ='model.';
-		trunkprefix   ='';
 		steps         =[];
 		requestedsteps=[0];
-		upload_server='';
-		upload_path='';
-		upload_login='';
-		upload_port=0;
-		download=0;
 		%}}}
 	end
 	methods
-		function org=organizer(varargin) % {{{
+		function org=xorganizer(varargin) % {{{
 
 			%process options
@@ -52,24 +45,9 @@
 			org.requestedsteps=getfieldvalue(options,'steps',0);
 
-			%Get trunk prefix (only if provided by user)
-			if exist(options,'trunkprefix'),
-				trunkprefix=getfieldvalue(options,'trunkprefix','');
-				if ~ischar(trunkprefix),                                 error('trunkprefix is not a string'); end
-				if ~strcmp(regexprep(trunkprefix,'\s+',''),trunkprefix), error('trunkprefix should not have any white space'); end
-				org.trunkprefix=trunkprefix;
-			end
-
-			%Get upload information, if provided
-			org.upload_server=getfieldvalue(options,'upload_server','');
-			org.upload_path=getfieldvalue(options,'upload_path','');
-			org.upload_login=getfieldvalue(options,'upload_login','');
-			org.upload_port=getfieldvalue(options,'upload_port',0);
-			org.download=getfieldvalue(options,'download',0);
-
 		end
 		%}}}
 		function disp(org) % {{{
 			disp(sprintf('   Repository: ''%s''',org.repository));
-			disp(sprintf('   Prefix:     ''%s''',org.prefix));
+			disp(sprintf('   Prefix:     ''%s''\n',org.prefix));
 			if isempty(org.steps)
 				disp('   no step');
@@ -78,12 +56,4 @@
 					disp(sprintf('   step #%2i: ''%s''',org.steps(i).id,org.steps(i).string));
 				end
-			end
-			if isempty(org.upload_server),
-				disp('   no upload info');
-			else
-				disp(sprintf('   upload_server:     ''%s''',org.upload_server));
-				disp(sprintf('   upload_login:     ''%s''',org.upload_login));
-				disp(sprintf('   upload_path:     ''%s''',org.upload_path));
-				disp(sprintf('   upload_port:     ''%i''',org.upload_port));
 			end
 		end
@@ -123,17 +93,6 @@
 			end
 
-			%If we are here, the model has not been found. Try trunk prefix if provided
-			if ~isempty(org.trunkprefix),
-				path2=[org.repository '/' org.trunkprefix string];
-				if ~exist(path2,'file'),
-					error(['Could find neither ' path ', nor ' path2]);
-				else
-					disp(['--> Branching ' org.prefix ' from trunk ' org.trunkprefix]);
-					md=loadmodel(path2);
-					return;
-				end
-			else
-				error(['Could not find ' path ]);
-			end
+			%If we are here, the data has not been found. 
+			error(['Could not find ' path ]);
 		end%}}}
 		function loaddata(org,string),% {{{
@@ -149,21 +108,17 @@
 			end
 
-			%If we are here, the data has not been found. Try trunk prefix if provided
-			if ~isempty(org.trunkprefix),
-				path2=[org.repository '/' org.trunkprefix string];
-				if ~exist(path2,'file'),
-					error(['Could find neither ' path ', nor ' path2]);
-				else
-					disp(['--> Branching ' org.prefix ' from trunk ' org.trunkprefix]);
-					evalin('caller',['load -mat ' path2]);
-					return;
-				end
-			else
-				error(['Could not find ' path ]);
-			end
+			%If we are here, the data has not been found. 
+			error(['Could not find ' path ]);
 		end%}}}
-		function bool=perform(org,string) % {{{
+		function bool=perform(org,varargin) % {{{
 
 			bool=false;
+			
+			%group,string are the variable arguments length: 
+			if nargin==2,
+				string=varargin{1};
+			elseif nargin==3,
+				string=sprintf('%s.%s',varargin{1},varargin{2});
+			end
 
 			%Some checks
@@ -192,24 +147,4 @@
 				bool=true;
 			end
-
-			%But if download is requested, we are downloading and skipping the step: 
-			if ismember(org.currentstep,org.requestedsteps) & org.download,
-				%load the model if it exists, and download
-				name=[org.repository '/' org.prefix org.steps(org.currentstep).string ];
-				if exist(name,'file'),
-					md=loadmodel(name); 
-					if isa(md,'model'),
-						if ~isempty(md.settings.upload_filename),
-							disp(sprintf('   downloading model'));
-							md=download(md);
-							save(name,'md','-v7.3');
-						end
-					end
-				end
-
-				%reset bool to false, so we stick with only downloading
-				bool=false;
-			end
-
 		end%}}}
 		function savemodel(org,md) % {{{
@@ -1,3 +1,3 @@
-%ORGANIZER class definition
+%XORGANIZER class definition
 %
 %   Supported options:
